@@ -70,7 +70,7 @@ class interface(abstract_interface):
         list_valid_devices = self.instrument.list_devices()
         if(len(list_valid_devices)>0):
             list_IDNs_and_devices = [dev[1] + " --> " + dev[0] for dev in list_valid_devices] 
-            self.combo_Devices.addItems(list_IDNs_and_devices)  
+            self.gui.combo_Devices.addItems(list_IDNs_and_devices)  
         self.logger.info(f"Found {len(list_valid_devices)} devices.") 
 
     def connect_device(self,device_full_name):
@@ -89,10 +89,7 @@ class interface(abstract_interface):
             self.logger.info(f"Connected to device {device_name}.")
             self.connected_device_name = device_name
             self.set_connected_state()
-            self.populate_combo_time_constants()
-            self.read_time_constant()
-            self.populate_combo_sensitivities()
-            self.read_sensitivity()
+
             self.start_reading()
         else: #If connection was not successful
             self.logger.error(f"Error: {Msg}")
@@ -111,6 +108,19 @@ class interface(abstract_interface):
             self.set_disconnected_state()
         else: #If disconnection was not successful
             self.logger.error(f"Error: {Msg}")
+            
+    def set_disconnected_state(self):
+        self.gui.set_disconnected_state()
+
+    def set_connecting_state(self):
+        self.gui.set_connecting_state()
+
+    def set_connected_state(self):
+        self.gui.set_connected_state()
+        self.populate_combo_time_constants()
+        self.read_time_constant()
+        self.populate_combo_sensitivities()
+        self.read_sensitivity()
 
     def set_auto_scale(self):
         ID = self.instrument.set_auto_scale()
@@ -119,21 +129,20 @@ class interface(abstract_interface):
         else:
             self.logger.info(f"'auto scale' set correctly.")
 
-
     def populate_combo_time_constants(self):
         self.logger.info(f"Reading all possible values of time constants from device...")
         self.time_constants = self.instrument.time_constants
-        self.combo_TimeConstants.clear() #First we empty the combobox
+        self.gui.combo_TimeConstants.clear() #First we empty the combobox
         if len(self.time_constants)>0:
-                self.combo_TimeConstants.addItems([str(tc) for tc in self.time_constants])  
+                self.gui.combo_TimeConstants.addItems([str(tc) for tc in self.time_constants])  
         self.logger.info(f"The device supports {len(self.time_constants)} different time constants.") 
         
     def populate_combo_sensitivities(self):
         self.logger.info(f"Reading all possible values of sensitivities from device...")
         self.sensitivities = self.instrument.sensitivities
-        self.combo_Sensitivities.clear() #First we empty the combobox
+        self.gui.combo_Sensitivities.clear() #First we empty the combobox
         if len(self.sensitivities)>0:
-                self.combo_Sensitivities.addItems([str(s) for s in self.sensitivities])  
+                self.gui.combo_Sensitivities.addItems([str(s) for s in self.sensitivities])  
         self.logger.info(f"The device supports {len(self.sensitivities)} different sensitivities.") 
 
     def read_time_constant(self):
@@ -142,7 +151,7 @@ class interface(abstract_interface):
         if self.time_constant == None:
             self.logger.error(f"An error occurred while reading the time constant from this device.")
             return
-        self.combo_TimeConstants.setCurrentIndex(self.time_constant)
+        self.gui.combo_TimeConstants.setCurrentIndex(self.time_constant)
         self.logger.info(f"Current time constant is {self.time_constants[self.time_constant]} (index={self.time_constant})...") 
         
     def set_time_constant(self,tc): 
@@ -168,7 +177,7 @@ class interface(abstract_interface):
         if self.sensitivity == None:
             self.logger.error(f"An error occurred while reading the sensitivity from this device.")
             return
-        self.combo_Sensitivities.setCurrentIndex(self.sensitivity)
+        self.gui.combo_Sensitivities.setCurrentIndex(self.sensitivity)
         self.logger.info(f"Current sensitivity is {self.sensitivities[self.sensitivity]} (index={self.sensitivity})...") 
         
     def set_sensitivity(self,s): 
@@ -211,10 +220,10 @@ class interface(abstract_interface):
             self.logger.error(f"No device is connected.")
             return
         self.logger.info(f"Updating refresh time before starting reading...")
-        if not(self.press_enter_refresh_time()): #read the current value in the refresh_time textbox, and validates it. The function returns True/False if refresh_time was valid
+        if not(self.gui.press_enter_refresh_time()): #read the current value in the refresh_time textbox, and validates it. The function returns True/False if refresh_time was valid
             return
         
-        self.set_reading_state() # Change some widgets
+        self.gui.set_reading_state() # Change some widgets
 
         self.continuous_read = True #Until this variable is set to True, the function Update will be repeated continuosly 
         self.logger.info(f"Starting reading from device {self.connected_device_name}...")
@@ -226,7 +235,7 @@ class interface(abstract_interface):
         #Sets self.ContinuousRead to 0 (this will force the function Update() to stop calling itself)
         self.continuous_read = False
         self.logger.info(f"Paused reading from device {self.connected_device_name}.")
-        self.set_pause_state() # Change some widgets
+        self.gui.set_pause_state() # Change some widgets
         return
 
     def stop_reading(self):
@@ -235,7 +244,7 @@ class interface(abstract_interface):
         self.stored_powers = []
         self.update() #We call one more time the self.Update() function to make sure plots is cleared. Since self.continuous_read is already set to False, Update() will not acquire data anymore
         self.logger.info(f"Stopped reading from device {self.connected_device_name}. All stored data have been deleted.")
-        self.set_stopped_state() # Change some widgets
+        self.gui.set_stopped_state() # Change some widgets
         # ...
         return
         
@@ -261,9 +270,9 @@ class interface(abstract_interface):
 
             for k in self.output.keys():
                 try:
-                    self.edit_Output[k].setText(f"{self.output[k]:.2e}")
+                    self.gui.edit_Output[k].setText(f"{self.output[k]:.2e}")
                 except:
-                    self.edit_Output[k].setText(f"nan")
+                    self.gui.edit_Output[k].setText(f"nan")
             QtCore.QTimer.singleShot(int(self.refresh_time*1e3), self.update)
            
         return
@@ -446,16 +455,16 @@ class gui(abstract_gui):
         self.interface.set_auto_scale()
 
     def click_combo_time_constants(self):
-        self.set_time_constant(self.combo_TimeConstants.currentIndex())
+        self.interface.set_time_constant(self.combo_TimeConstants.currentIndex())
 
     def click_combo_sensitivities(self):
-        self.set_sensitivity(self.combo_Sensitivities.currentIndex())
+        self.interface.set_sensitivity(self.combo_Sensitivities.currentIndex())
        
     def click_button_StartPauseReading(self): 
-        if(self.continuous_read == False):
-            self.start_reading()
-        elif (self.continuous_read == True):
-            self.pause_reading()
+        if(self.interface.continuous_read == False):
+            self.interface.start_reading()
+        elif (self.interface.continuous_read == True):
+            self.interface.pause_reading()
         return
 
     def click_button_StopReading(self):
